@@ -77,5 +77,6 @@ async def search_v1_get(
         return json(result, 200)
     # pylint: disable=broad-except
     except Exception as err:
-        logger.error(err)
-        return json({"error": err.__repr__()}, 400)
+        error = getattr(err, 'message', repr(err))
+        logger.error(error)
+        return json({"error": error}, 400)
